@@ -18,6 +18,59 @@ drgeeData <-
         elink <- match.arg(elink)
         estimation.method <- match.arg(estimation.method)
 
+        response.ok <- function (x, link = "identity") {
+
+            if (is.factor(x)) {
+
+                if (link != "logit"){
+                    stop("\nFactor response only possible for the logit link\n\n");
+                    return(FALSE);
+                }
+
+                if(nlevels(x) != 2){
+                    stop("\nThe response in logistic regression needs to be binary\n\n");
+                    return(FALSE);
+                } else {
+                    return(TRUE);
+                }
+
+            } else if (is.vector(x) & is.numeric(x)) {
+
+                if (link == "log"){
+
+                    if (min(x, na.rm = TRUE) < 0) {
+                        stop("\nThe response in log-linear regression needs to be non-negative\n\n");
+                        return(FALSE);
+                    } else {
+                        return(TRUE);
+                    }
+
+                } else if (link == "logit") {
+
+                    if (min(x, na.rm = TRUE) < 0 | max(x, na.rm = TRUE) > 1) {
+                        stop("\nThe response in logistic regression needs to be between 0 and 1\n\n");
+                        return(FALSE);
+                    } else if (any(x != 0 & x != 1, na.rm = TRUE)) {
+                        warning("\nnon-integer response in logistic regression\n\n");
+                        return(TRUE);
+                    } else {
+                        return(TRUE);
+                    }
+
+                } else {
+                    return(TRUE);
+                }
+
+            } else {
+
+                stop("\nThe response the regression needs to be a factor or a numeric vector\n\n");
+                return(FALSE);
+
+            }
+
+        }
+
+
         if (missing(data)) {
             data <- parent.frame()
         }
@@ -33,28 +86,36 @@ drgeeData <-
                 outname <- NULL
             }
         } else {
-            oterms <- NULL
-            outname <- NULL
+
+            if(estimation.method %in% c("dr", "o")) {
+                stop("\nAn outcome nuisance model is needed\n\n");
+            } else {
+                oterms <- NULL;
+                outname <- NULL;
+            }
         }
 
         ## Extract the outcome if it is given
         if (!missing(outcome)) {
 
-            if (!is.null(outname)) {
-                warning(paste("\nDuplicate specifications of the outcome, using ",
-                              outname, "\n\n") )
-            }
-
             ## If the outcome is not given as a string
             ## get the name of the object that was given
             ## as input
             if (is.character(outcome)) {
                 outname <- outcome
             } else {
-                outname <- call[["outcome"]]
+                outname <- as.character(call$outcome)
             }
+
+            if (!missing(oformula)) {
+                warning(paste("\nDuplicate specifications of the outcome, using ",
+                              outname, "from the outcome argument\n\n") )
+            }
+
         }
 
+
+
         if (is.null(outname)) {
             stop("An outcome needs to be specified\n\n")
         } else {
@@ -69,7 +130,7 @@ drgeeData <-
 
             if (dim(y.all)[2] != 2) {
                 stop("\nThe outcome needs to be of exactly one dimension\n
-or a factor with two levels")
+or a factor with two levels\n\n")
             }
 
             y <- y.all[, 2, drop = F]
@@ -77,18 +138,14 @@ or a factor with two levels")
             ## Update the column names if the outcome was not numeric
             outname <- colnames(y)
 
-            if (olink == "logit" & length(unique(y[which(!is.na(y)), ])) != 2) {
-                stop("For outcome link logit, the outcome needs to be binary\n\n")
-            }
-
-            if (olink == "log" & min(y, na.rm = TRUE) < 0) {
-                stop("When outcome link is log the outcome needs to be positive\n\n")
+            if (!response.ok(y[, 1, drop=TRUE], link = olink)) {
+                stop("\nBad outcome!\n\n")
             }
 
             nobs <- nrow(y)
 
             ## Identify complete observations
-            compl.rows <- !is.na(as.vector(y))
+            compl.rows <- !is.na(y[, 1])
 
         }
 
@@ -123,18 +180,34 @@ or a factor with two levels")
             }
 
         } else {
-            eterms <- NULL
-            expname <- NULL
+
+            if(estimation.method %in% c("dr", "e")) {
+                stop("\nAn exposure nuisance model is needed\n\n");
+            } else {
+                eterms <- NULL
+                expname <- NULL
+            }
+
         }
 
         ## Extract the exposure if it is given
         if (!missing(exposure)) {
 
+
+            ## If the exposure is not given as a string
+            ## get the name of the object that was given
+            ## as input
             if (is.character(exposure)) {
                 expname <- exposure
             } else {
-                expname <- call[["exposure"]]
+                expname <- as.character(call$exposure)
             }
+
+            if (!missing(eformula)) {
+                warning(paste("\nDuplicate specifications of the exposure, using ",
+                              expname, "from the exposure argument\n\n") )
+            }
+
         }
 
         if (!is.null(expname)) {
@@ -150,7 +223,7 @@ or a factor with two levels")
 
             if (dim(a.all)[2] != 2) {
                 stop("\nThe exposure needs to be of exactly one dimension\n
-or a factor with two levels")
+or a factor with two levels\n\n")
             }
 
             a <- a.all[, 2, drop = F]
@@ -164,12 +237,11 @@ or a factor with two levels")
                 compl.rows <- compl.rows & !is.na(as.vector(a))
             }
 
-            if (elink == "logit" & length(unique(a[which(!is.na(a)), ])) != 2) {
-                stop("For exposure link logit, the exposure needs to be binary\n\n")
-            }
-
-            if (elink == "log" & min(a, na.rm = TRUE) < 0) {
-                stop("When exposure link is log the exposure needs to be positive\n\n")
+            if (estimation.method %in% c("dr", "e")) {
+                if (!response.ok(a[, 1, drop=TRUE], link = elink) &
+                    estimation.method != "o") {
+                    stop("\nBad exposuree!\n")
+                }
             }
 
         } else {
@@ -253,7 +325,7 @@ or a factor with two levels")
                 id.tmp <- as.factor(id[obs.order])
                 y.tmp <- y[obs.order, 1]
                 ## For each cluster, identify the number of different values for the outcome
-                ni.vals <- ave(as.vector(y.tmp), id.tmp, FUN = function(y) {length(unique(y[which(!is.na(y)), ]))})
+                ni.vals <- ave(as.vector(y.tmp), id.tmp, FUN = function(y) {length(unique(y[which(!is.na(y)) ]))})
 
                 ## Only use outcome-discordant clusters
                 compl.rows <- compl.rows & (ni.vals > 1)
@@ -263,7 +335,7 @@ or a factor with two levels")
                 id.tmp <- as.factor(id[obs.order])
                 a.tmp <- a[obs.order, 1]
                 ## For each cluster, identify the number of different values for the outcome
-                ni.vals <- ave(as.vector(a.tmp), id.tmp, FUN = function(y) {length(unique(y[which(!is.na(y)), ]))})
+                ni.vals <- ave(as.vector(a.tmp), id.tmp, FUN = function(a) {length(unique(a[which(!is.na(a))]))})
 
                 ## Only use outcome-discordant clusters
                 compl.rows <- compl.rows & (ni.vals > 1)
